netapp_ontap.models.chassis_nodes_usbs API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.chassis_nodes_usbs`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ChassisNodesUsbsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ChassisNodesUsbs object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET POST PATCH`

    Indicates whether or not the USB ports are enabled.

  `ports: List[ChassisNodesUsbsPorts] GET POST PATCH`

    The ports field of the chassis_nodes_usbs.

  `supported: bool GET POST PATCH`

    Indicates whether or not USB ports are supported on the current platform.